# kataphron
Python package containing informations about Kataphrons.

This will allow you do better understand their core mechanics, ads and cons and also lokk at them from bot lore and modeling perspective.